/*
 * Copyright [2011] [Risk Focus Inc]
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
grammar DateRangeDsl;

options { output=AST; }

tokens
{
  RANGESTART='from';
  RANGEEND='to';
  RELATIVE='relative';
  ABSOLUTE='absolute';
}

@header {
 package com.riskfocus.util.daterangedsl.parser;
}

dateRangeModel: '/from/' rangeBegin '/to/' rangeEnd -> 'from' rangeBegin 'to' rangeEnd;

rangeBegin: (relativePeriodPast | absoluteDate) thisTime ;
	
relativePeriodPast: relativePeriodPastOptions -> 'relative' relativePeriodPastOptions;
	
relativePeriodPastOptions: 'yesterday' | relativePeriodPastOption1;	

relativePeriodPastOption1: Number '/' Period '/back' -> Number Period;

thisTime: '/thistime'?;

rangeEnd: ((relativePeriodFuture | absoluteDate) thisTime) | 'now';

relativePeriodFuture:	relativePeriodFutureOptions -> 'relative' relativePeriodFutureOptions;

relativePeriodFutureOptions: Number '/' Period '/later' -> Number Period;

Period: 'seconds' | 'minutes' | 'hours' | 'days' | 'weeks' | 'months' | 'years';

absoluteDate: Number -> 'absolute' Number;
  
Number:	('0'..'9')+;
